/*
DL2 Monitor: ./pa/lcp.h
Copyright (C) 2002, Rolf Jger, Ulm (Germany)

See the file README for information on usage and redistribution
of this source code file, and for a DISCLAIMER OF ALL WARRANTIES.
*/

/*----------------------------------------------------------------------------
 * Datalink Monitor (lcp): Packet Type PPP/LCP (RFC1661)
 * creates the Pa_Packet object pa_lcp: see pa.h for details. 
 *
 * Author: Rolf Jger,Ulm
 *----------------------------------------------------------------------------
 * YYYYMMDD  History
 * 20020427  length introduced. 
 * 20020410  attention to reserved verbose flags. 
 * 20020405  accm: Async control character map introduced.
 * 20020330  created from scratch
 * $Id: lcp.h,v 1.6 2002/04/29 12:58:38 dv Exp $
 *----------------------------------------------------------------------------
*/
# ifndef __LCP_H__
# define __LCP_H__
# include "pa/pa.h"

static Pa_Config pa_lcp_field[] = {
  {"code","C",0},
  {"request-id","RI",1},
  {"length","L",2},
  {"data","PD",3},
  {"options","",4},
  {"mru","MRU",5},
  {"authentication-protocol","AP",6},
  {"quality-protocol","QP",7},
  {"magic-number","MN",8},
  {"pf-compression","PFC",9},
  {"acf-compression","AFC",10},
  {"accm","ACC",11},
  {"echo-data","ED",12},
  {"other-data","OD",13},
  {NULL,NULL,-1}
};
const Pa_Packet pa_lcp = {"lcp",pa_lcp_field};

# define LCP_Mcode		0x00000001
# define LCP_Mrequest_id	0x00000002
# define LCP_Mlength		0x00000004
# define LCP_Mdata		0x00000008
# define LCP_Moptions		0x00000010
# define LCP_Mmru		0x00000020
# define LCP_Mauth_protocol	0x00000040
# define LCP_Mqual_protocol	0x00000080
# define LCP_Mmagic_number	0x00000100
# define LCP_Mpf_compression	0x00000200
# define LCP_Macf_compression	0x00000400
# define LCP_Maccm		0x00000800
# define LCP_Mecho_data		0x00001000
# define LCP_Mother_data	0x00002000
# define LCP_Mdefault		PA_VMdefault
# define LCP_Mpacket_length	PA_VMpacket_length

# define LCP_F(i)		pa_lcp_field[i].oname
# define LCP_Fcode		LCP_F(0)
# define LCP_Frequest_id	LCP_F(1)
# define LCP_Flength		LCP_F(2)
# define LCP_Fdata		LCP_F(3)
# define LCP_Foptions		LCP_F(4)
# define LCP_Fmru		LCP_F(5)
# define LCP_Fauth_protocol	LCP_F(6)
# define LCP_Fqual_protocol	LCP_F(7)
# define LCP_Fmagic_number	LCP_F(8)
# define LCP_Fpf_compression	LCP_F(9)
# define LCP_Facf_compression	LCP_F(10)
# define LCP_Faccm		LCP_F(11)
# define LCP_Fecho_data		LCP_F(12)
# define LCP_Fother_data	LCP_F(13)
# define LCP_Fpacket_length	PA_VFpacket_length
//#undef LCP_F(i)

# endif /*__LCP_H__*/
